==> haskell-wai-app-static-3.1.5-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.5
id: wai-app-static-3.1.5-Kh7qLBHMaBzDTT3YhZBduH
key: wai-app-static-3.1.5-Kh7qLBHMaBzDTT3YhZBduH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: 8cd77f4f0b9f1483c78fa7594a4bd16a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-app-static-3.1.5
hs-libraries: HSwai-app-static-3.1.5-Kh7qLBHMaBzDTT3YhZBduH
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.17-KyUY3QlaeIZ9iMNzKLz7fi
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-J0QH2yOD00d1kgYU4oKQvq
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    memory-0.13-9YH63fsEcp4AuUH5L0KHp
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.12.1.0-4FckWvtE7Gp1EYdm7OVbJw
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
    wai-extra-3.0.15.2-5kamB4j8CxXJtWL54vp4wE
    warp-3.2.6-38JsZEZsOWgKZZpk0gxmV3
    zlib-0.6.1.1-IKN2DpYEe8r3bYFvs7BDUW
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.5-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.5
id: wai-app-static-3.1.5-LvPZUBEtklc70XODmnZMTT
key: wai-app-static-3.1.5-LvPZUBEtklc70XODmnZMTT
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: d197cb37229591b78e4e9ab04e98bf1e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-app-static-3.1.5
hs-libraries: HSwai-app-static-3.1.5-LvPZUBEtklc70XODmnZMTT
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.17-KyUY3QlaeIZ9iMNzKLz7fi
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-J0QH2yOD00d1kgYU4oKQvq
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    memory-0.13-9YH63fsEcp4AuUH5L0KHp
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.12.1.0-4FckWvtE7Gp1EYdm7OVbJw
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
    wai-extra-3.0.15.3-65UbAIAwuA6BWb9IkuPpmE
    warp-3.2.7-9t3RpqrAcaE2QuqpNopZDW
    zlib-0.6.1.1-IKN2DpYEe8r3bYFvs7BDUW
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
